@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * based on the Null Theme Engine for Gtk+.
 * Copyright (c) 2008 Robert Staudinger <robert.staudinger@gmail.com>
@@ -74,6 +74,7 @@ namespace Oxygen
                 GtkWidget* button( gtk_button_new_with_label( "Normal" ) );
                 gtk_table_attach( GTK_TABLE( table ), button, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 2, 0  );
                 gtk_widget_show( button );
+                gtk_widget_set_tooltip_text( button, "This is a normal, text only button" );
 
                 // combobox model
                 GtkListStore* model( gtk_list_store_new( 1, G_TYPE_STRING ) );
@@ -104,6 +105,7 @@ namespace Oxygen
 
                 gtk_table_attach( GTK_TABLE( table ), comboBox, 2, 3, 0, 1, GTK_FILL, GTK_FILL, 2, 0 );
                 gtk_widget_show( comboBox );
+                gtk_widget_set_tooltip_text( comboBox, "This is a normal, text only combo box" );
 
             }
 
@@ -119,11 +121,15 @@ namespace Oxygen
 
                 GtkIconTheme* theme( gtk_icon_theme_get_default() );
                 GdkPixbuf* icon = gtk_icon_theme_load_icon( theme, "oxygen", 16, (GtkIconLookupFlags) 0, 0L );
-                GtkWidget* image( gtk_image_new_from_pixbuf( icon ) );
-                g_object_unref( icon );
+                if(icon)
+                {
+                    GtkWidget* image( gtk_image_new_from_pixbuf( icon ) );
+                    g_object_unref( icon );
 
-                gtk_button_set_image( GTK_BUTTON( button ), image );
+                    gtk_button_set_image( GTK_BUTTON( button ), image );
+                }
                 gtk_widget_show( button );
+                gtk_widget_set_tooltip_text( button, "This is a normal, text and icon button" );
 
                 // combobox model
                 GtkListStore* model( gtk_list_store_new( 2, GDK_TYPE_PIXBUF, G_TYPE_STRING ) );
@@ -176,6 +182,7 @@ namespace Oxygen
 
                 gtk_table_attach( GTK_TABLE( table ), comboBox, 2, 3, 1, 2, GTK_FILL, GTK_FILL, 2, 0 );
                 gtk_widget_show( comboBox );
+                gtk_widget_set_tooltip_text( comboBox, "This is a normal, text and icon combo box" );
 
             }
 
@@ -277,7 +284,7 @@ namespace Oxygen
                 gtk_widget_show( comboBox );
 
                 // connection
-                _toolBarStyleChangedId.connect( G_OBJECT( comboBox ), "changed", G_CALLBACK( toolBarStyleChanged ), this );
+                connect( G_OBJECT( comboBox ), "changed", G_CALLBACK( toolBarStyleChanged ), this );
 
             }
 
@@ -321,7 +328,7 @@ namespace Oxygen
                 gtk_widget_show( comboBox );
 
                 // connection
-                _iconSizeChangedId.connect( G_OBJECT( comboBox ), "changed", G_CALLBACK( iconSizeChanged ), this );
+                connect( G_OBJECT( comboBox ), "changed", G_CALLBACK( iconSizeChanged ), this );
 
             }
 
