@@ -2,7 +2,7 @@
 #define oxygenstyle_h
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 * Copyright (c) 2010 Ruslan Kabatsayev <b7.10110111@gmail.com>
 *
 * This  library is free  software; you can  redistribute it and/or
@@ -29,6 +29,7 @@
 #include "oxygengeometry.h"
 #include "oxygengtkcellinfo.h"
 #include "oxygengtkgap.h"
+#include "oxygenloghandler.h"
 #include "oxygenmetrics.h"
 #include "oxygenqtsettings.h"
 #include "oxygenshadowhelper.h"
@@ -39,8 +40,13 @@
 #include "oxygenwindecooptions.h"
 #include "oxygenwindecobutton.h"
 #include "oxygenwindowmanager.h"
+
 #include <gdk/gdk.h>
 
+#ifdef GDK_WINDOWING_X11
+#include <X11/Xdefs.h>
+#endif
+
 namespace Oxygen
 {
 
@@ -61,7 +67,7 @@ namespace Oxygen
         }
 
         //! initialize
-        void initialize( unsigned int flags = QtSettings::All );
+        bool initialize( unsigned int flags = QtSettings::All );
 
         //! settings
         const QtSettings& settings( void ) const
@@ -105,16 +111,19 @@ namespace Oxygen
         //! background surface
         bool hasBackgroundSurface( void ) const;
 
+        //! update kwin blur region
+        void setWindowBlur(GdkWindow* window,bool enable);
+
         //!@name primitives
         //@{
 
         //! fill given rectangle with flat color
         void fill( GdkWindow* window, GdkRectangle* r, gint x, gint y, gint w, gint h, Palette::Role role ) const
-        { fill( window, r, x, y, w, h, settings().palette().color( Palette::Active, role ) ); }
+        { fill( window, r, x, y, w, h, _settings.palette().color( Palette::Active, role ) ); }
 
         //! fill given rectangle with flat color
         void fill( GdkWindow* window, GdkRectangle* r, gint x, gint y, gint w, gint h, Palette::Group group, Palette::Role role ) const
-        { fill( window, r, x, y, w, h, settings().palette().color( group, role ) ); }
+        { fill( window, r, x, y, w, h, _settings.palette().color( group, role ) ); }
 
         //! fill given rectangle with flat color
         void fill( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const ColorUtils::Rgba& color ) const;
@@ -127,13 +136,21 @@ namespace Oxygen
 
         //! window background
         /*! returns true if window gradient could be rendered */
-        bool renderWindowBackground( cairo_t*, GdkWindow*, GtkWidget*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions& = StyleOptions(), TileSet::Tiles = TileSet::Center );
+        bool renderWindowBackground( cairo_t*, GdkWindow*, GtkWidget*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions& = StyleOptions(), bool isMaximized=false );
+        bool renderWindowBackground( GdkWindow* window, GtkWidget* widget, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o = StyleOptions() )
+        { return renderWindowBackground( 0L, window, widget, r, x, y, w, h, o ); }
 
-        bool renderWindowBackground( GdkWindow* window, GtkWidget* widget, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o = StyleOptions(), TileSet::Tiles tiles= TileSet::Center )
-        { return renderWindowBackground( 0L, window, widget, r, x, y, w, h, o, tiles ); }
+        bool renderWindowBackground( cairo_t* c, gint x, gint y, gint w, gint h, StyleOptions& options, bool maximized )
+        { return renderWindowBackground( c, 0L, 0L, 0L, x, y, w, h, options, maximized ); }
 
-        bool renderWindowBackground( GdkWindow* window, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o = StyleOptions(), TileSet::Tiles tiles = TileSet::Center)
-        { return renderWindowBackground( window, 0L, r, x, y, w, h, o, tiles ); }
+        bool renderWindowBackground( GdkWindow* window, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o = StyleOptions())
+        { return renderWindowBackground( window, 0L, r, x, y, w, h, o ); }
+
+        // render background gradient
+        bool renderBackgroundGradient( cairo_t*, GdkWindow*, GtkWidget*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions& = StyleOptions(), bool isMaximized=false );
+
+        // render background pixmap
+        bool renderBackgroundPixmap( cairo_t*, GdkWindow*, GtkWidget*, GdkRectangle*, gint, gint, gint, gint, bool isMaximized=false );
 
         //! groupbox background
         bool renderGroupBoxBackground( GdkWindow* window, GtkWidget* widget, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o, TileSet::Tiles tiles = TileSet::Center )
@@ -142,7 +159,9 @@ namespace Oxygen
         bool renderGroupBoxBackground( cairo_t*, GdkWindow*, GtkWidget*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions&, TileSet::Tiles = TileSet::Center );
 
         //! menu background
-        bool renderMenuBackground( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions& ) const;
+        bool renderMenuBackground( GdkWindow*, Cairo::Context&, gint, gint, gint, gint, const StyleOptions& ) const;
+        bool renderMenuBackground( GdkWindow* window, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o) const
+        { Cairo::Context c(window,r); return renderMenuBackground(window, c, x, y, w, h, o); }
 
         //! tooltip background
         void renderTooltipBackground( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions& ) const;
@@ -299,6 +318,12 @@ namespace Oxygen
         //! sanitize size
         void sanitizeSize( GdkWindow* window, gint& width, gint& height ) const;
 
+        //! draw tab close x icon
+        void renderTabCloseIcon(cairo_t* context, GdkRectangle* r) const;
+
+        //! draw tab close button
+        void renderTabCloseButton(cairo_t* context, GdkRectangle* r, const ColorUtils::Rgba& base, const ColorUtils::Rgba& color);
+
         // get tiles for given tab orientation
         TileSet::Tiles tabTiles( GtkPositionType position ) const
         {
@@ -319,8 +344,7 @@ namespace Oxygen
         protected:
 
         //! constructor
-        explicit Style( void )
-        {}
+        Style( void );
 
         //! get color matching role from either style option or default palette
         const ColorUtils::Rgba& color( Palette::Role role, const StyleOptions& option ) const
@@ -330,7 +354,7 @@ namespace Oxygen
         const ColorUtils::Rgba& color( Palette::Group group, Palette::Role role, const StyleOptions& option ) const
         {
             Palette::ColorSet::const_iterator iter( option._customColors.find( role ) );
-            return iter == option._customColors.end() ? settings().palette().color( group, role ) : iter->second;
+            return iter == option._customColors.end() ? _settings.palette().color( group, role ) : iter->second;
         }
 
         //! set background surface
@@ -411,6 +435,9 @@ namespace Oxygen
 
         //@}
 
+        //! monitored files is changed
+        static void fileChanged( GFileMonitor*, GFile*, GFile*, GFileMonitorEvent, gpointer );
+
         //! used to store slab characteristics
         class SlabRect
         {
@@ -448,13 +475,16 @@ namespace Oxygen
 
         private:
 
-        // Qt settings
+        //! log handler
+        LogHandler _logHandler;
+
+        //! Qt settings
         QtSettings _settings;
 
-        // helper
+        //! helper
         StyleHelper _helper;
 
-        // animations
+        //! animations
         Animations _animations;
 
         //! argb helper
@@ -495,6 +525,11 @@ namespace Oxygen
         //! Tab close buttons
         TabCloseButtons _tabCloseButtons;
 
+        #ifdef GDK_WINDOWING_X11
+        //! Atom to show kwin what regions of translucent windows should be blurred
+        Atom _blurAtom;
+        #endif
+
         //! singleton
         static Style* _instance;
 
